package com.sbytestream.demos.SimpleRest;

import org.apache.coyote.Response;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;

@RestController
@RequestMapping("/api/books")
public class BooksController {
    public BooksController() {
        initialize();
    }

    @GetMapping()
    public List<Book> all() {
        return _books;
    }

    @PostMapping()
    public void add(@RequestBody Book book) {
        book.setId(++LAST_ID);
        _books.add(book);
    }

    @PutMapping()
    public ResponseEntity<Book> update(@RequestBody Book book) {
        Book existingBook = _books.stream().filter(b -> b.getId() == book.getId()).findAny().orElse(null);
        if (existingBook == null) {
            return new ResponseEntity<Book>(existingBook, HttpStatus.NOT_FOUND);
        }
        else {
            existingBook.setAuthor(book.getAuthor());
            existingBook.setCost(book.getCost());
            existingBook.setTitle(book.getTitle());
            return new ResponseEntity<Book>(existingBook, HttpStatus.OK);
        }
    }

    @DeleteMapping("/{id}")
    public ResponseEntity<Book> delete(@PathVariable("id") Integer id) {
        Book existingBook = _books.stream().filter(b -> b.getId() == id).findAny().orElse(null);
        if (existingBook == null) {
            return new ResponseEntity<Book>(existingBook, HttpStatus.NOT_FOUND);
        }
        else {
            _books.remove(existingBook);
            return new ResponseEntity<Book>(existingBook, HttpStatus.OK);
        }
    }

    private void initialize() {
        _books.add(new Book(++LAST_ID, "IT", "Stephen King", 300));
        _books.add(new Book(++LAST_ID,"Different Seasons", "Stephen King", 250));
        _books.add(new Book(++LAST_ID,"Robot Dreams", "Isaac Asimov", 450));
        _books.add(new Book(++LAST_ID,"I, Robot", "Isaac Asimov", 350));
    }

    private List<Book> _books = new ArrayList<Book>();
    private static int LAST_ID = 0;
}
